@@ -1,6 +1,8 @@
 import os
 from pathlib import Path
 
+import typer
+
 from ..exceptions.base_exception import DocrunnerBaseException
 from ..models.options import Options
 from ..utils.general import log_exception
@@ -36,6 +38,7 @@ def run_typescript(
     """
     
     startup_command = options.startup_command
+    final_exit_code = 0
 
     try:
         code_filepaths = create_language_files(
@@ -44,17 +47,24 @@ def run_typescript(
 
         if startup_command:
             startup_command = startup_command.replace('"', '')
-            os.system(startup_command)
+            exit_code = os.system(startup_command)
+            if exit_code != 0:
+                raise typer.Exit(code=exit_code)
             return
         
         for filepath in list(code_filepaths.keys()):
             compile_exit_code = compile_typescript(filepath=filepath)
             if compile_exit_code != 0:
-                return
+                final_exit_code = compile_exit_code
 
             filepath = filepath[0: -3]
             filepath += '.js'
-            os.system(f'node {filepath}')
+            run_exit_code = os.system(f'node {filepath}')
+            if run_exit_code != 0:
+                final_exit_code = run_exit_code
+        
+        if final_exit_code != 0:
+            raise typer.Exit(code=final_exit_code)
 
     except DocrunnerBaseException as error:
         log_exception(error)
